diff --git a/tests/test_extensions.py b/tests/test_extensions.py
index 7a18b9491..19a138974 100644
--- a/tests/test_extensions.py
+++ b/tests/test_extensions.py
@@ -775,8 +775,23 @@ def testAnchorLink(self):
'
'
)
- def testAnchorLinkWithInlineCode(self):
- """ Test TOC Anchorlink with inline code. """
+ def testAnchorLinkWithSingleInlineCode(self):
+ """ Test TOC Anchorlink with single inline code. """
+ md = markdown.Markdown(
+ extensions=[markdown.extensions.toc.TocExtension(anchorlink=True)]
+ )
+ text = '# This is `code`.'
+ self.assertEqual(
+ md.convert(text),
+ '' # noqa
+ )
+
+ def testAnchorLinkWithDoubleInlineCode(self):
+ """ Test TOC Anchorlink with double inline code. """
md = markdown.Markdown(
extensions=[markdown.extensions.toc.TocExtension(anchorlink=True)]
)
@@ -804,8 +819,22 @@ def testPermalink(self):
'' # noqa
)
- def testPermalinkWithInlineCode(self):
- """ Test TOC Permalink with inline code. """
+ def testPermalinkWithSingleInlineCode(self):
+ """ Test TOC Permalink with single inline code. """
+ md = markdown.Markdown(
+ extensions=[markdown.extensions.toc.TocExtension(permalink=True)]
+ )
+ text = '# This is `code`.'
+ self.assertEqual(
+ md.convert(text),
+ '' # noqa
+ 'This is code
.' # noqa
+ '' # noqa
+ '
' # noqa
+ )
+
+ def testPermalinkWithDoubleInlineCode(self):
+ """ Test TOC Permalink with double inline code. """
md = markdown.Markdown(
extensions=[markdown.extensions.toc.TocExtension(permalink=True)]
)